Name:           uhd
URL:            http://code.ettus.com/redmine/ettus/projects/uhd/wiki
Version:        3.5.3
Release:        %mkrel 3
Group:          Communications/Radio
Summary:        Universal Hardware Driver for Ettus Research products
License:        GPLv3+
Source0:        %{name}-%{version}.tar.gz
# Create tarball from git with:
# $ ./make-tarball uhd git://code.ettus.com/ettus/uhd.git
# See note in make-tarball script
Source1:        make-tarball

BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(orc-0.4)
BuildRequires:  python-cheetah
BuildRequires:  python-docutils
BuildRequires:  doxygen
BuildRequires:  pkgconfig

%description
The UHD is the universal hardware driver for Ettus Research products.
The goal of the UHD is to provide a host driver and API for current and
future Ettus Research products. It can be used standalone without GNU Radio.

%prep
%setup -q

%build
pushd host
%cmake
%make
popd

%install
%makeinstall_std -C host/build

# Allow access only to users in usrp group
sed -i 's/MODE:="0666"/MODE:="0660"/' %{buildroot}%{_datadir}/uhd/utils/uhd-usrp.rules
mkdir -p %{buildroot}%{_prefix}/lib/udev/rules.d
mv %{buildroot}%{_datadir}/uhd/utils/uhd-usrp.rules %{buildroot}%{_prefix}/lib/udev/rules.d/10-usrp-uhd.rules

# Remove binaries for tests, examples
rm -rf %{buildroot}%{_datadir}/uhd/{tests,examples}

# Move the utils stuff to libexec dir
mkdir -p %{buildroot}%{_libexecdir}/uhd
mv %{buildroot}%{_datadir}/uhd/utils/* %{buildroot}%{_libexecdir}/uhd

# Package base docs to base package
mkdir _tmpdoc
mv %{buildroot}%{_docdir}/%{name}/{AUTHORS.txt,LICENSE.txt,README.txt} _tmpdoc

%package devel
Summary:        Development files for UHD
Group:          Communications/Radio
Requires:       %{name} = %{version}-%{release}

%description devel
Development files for the Universal Hardware Driver (UHD).

%package doc
Summary:        Documentation files for UHD
Group:          Communications/Radio
BuildArch:      noarch

%description doc
Documentation for the Universal Hardware Driver (UHD).

%pre -n uhd
getent group usrp >/dev/null || groupadd -r usrp

%files
%doc _tmpdoc/*
%{_bindir}/uhd_find_devices
%{_bindir}/uhd_usrp_probe
%{_bindir}/uhd_cal_rx_iq_balance
%{_bindir}/uhd_cal_tx_dc_offset
%{_bindir}/uhd_cal_tx_iq_balance
%{_bindir}/uhd_images_downloader
%{_bindir}/usrp2_card_burner
%{_bindir}/usrp_n2xx_simple_net_burner
%{_prefix}/lib/udev/rules.d/10-usrp-uhd.rules
%{_libdir}/lib*.so.*
%{_libexecdir}/uhd

%files devel
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%doc %{_docdir}/%{name}/*
%{_mandir}/man1/*


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 3.5.3-3.mga4
+ Revision: 529658
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 fwang <fwang> 3.5.3-2.mga4
+ Revision: 452819
- rebuild for new boost

* Fri May 31 2013 barjac <barjac> 3.5.3-1.mga4
+ Revision: 433512
- new version 3.5.3

* Wed Apr 10 2013 barjac <barjac> 3.5.1-2.mga3
+ Revision: 409431
- rebuild for boost-1.53

* Fri Feb 01 2013 barjac <barjac> 3.5.1-1.mga3
+ Revision: 393856
- new version 3.5.1

* Mon Jan 14 2013 fwang <fwang> 3.5.0-2.mga3
+ Revision: 385731
- update udev rules dir

  + umeabot <umeabot>
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 barjac <barjac> 3.5.0-1.mga3
+ Revision: 341382
- new version 3.5.0

* Thu Dec 20 2012 fwang <fwang> 3.4.3-3.mga3
+ Revision: 333112
- rebuild for new boost

* Fri Sep 28 2012 barjac <barjac> 3.4.3-2.mga3
+ Revision: 299080
- Changed group to new policy

* Sat Sep 22 2012 barjac <barjac> 3.4.3-1.mga3
+ Revision: 296773
- New version 3.4.3

* Tue Jul 31 2012 fwang <fwang> 3.4.2-2.mga3
+ Revision: 276501
- rebuild for new boost

* Sat Jun 09 2012 barjac <barjac> 3.4.2-1.mga3
+ Revision: 258969
- New version 3.4.2
- changed BR libusb1.0-devel
- Minor edit to make-tarball script

* Wed May 30 2012 fwang <fwang> 3.4.1-2.mga3
+ Revision: 249873
- disable check
- drop unused command
- rebuild for new boost

* Sat Apr 21 2012 barjac <barjac> 3.4.1-1.mga2
+ Revision: 232342
- new version

* Sat Mar 03 2012 barjac <barjac> 3.3.2-1.mga2
+ Revision: 217237
- new version 3.3.2
- added make-tarball script for simpler updates

* Sat Jan 14 2012 barjac <barjac> 3.3.1-1.mga2
+ Revision: 196168
- Corrected Group in sub packages
- Cleaned
- Added BR orc
- Removed %%post, %%postun ldconfig
- Changed Group tag
- imported package uhd


* Fri Dec  2 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.1-1
- New version

* Thu Dec  1 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-3
- Updated summary to be more descriptive

* Wed Nov 30 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-2
- Fixed according to reviewer comments

* Tue Nov 01 2011 Jaroslav Škarvada <jskarvad@redhat.com> - 3.3.0-1
- Initial version
